searchData={"items":[{"type":"module","title":"MyApp.Cldr","doc":"Provides the core functions to retrieve and manage\nthe CLDR data that supports formatting and localisation.\n\nIt provides the core functions to access formatted\nCLDR data, set and retrieve a current locale and validate\ncertain core data types such as locales, currencies and\nterritories.","ref":"MyApp.Cldr.html"},{"type":"function","title":"MyApp.Cldr.available_locale_name?/1","doc":"","ref":"MyApp.Cldr.html#available_locale_name?/1"},{"type":"function","title":"MyApp.Cldr.default_locale/0","doc":"Returns the default `locale`.","ref":"MyApp.Cldr.html#default_locale/0"},{"type":"function","title":"Example - MyApp.Cldr.default_locale/0","doc":"iex> MyApp.Cldr.default_locale()\n    %Cldr.LanguageTag{\n      backend: MyApp.Cldr,\n      canonical_locale_name: \"en-001\",\n      cldr_locale_name: :\"en-001\",\n      language_subtags: [],\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-001\",\n      script: :Latn,\n      territory: :\"001\",\n      transform: %{},\n      language_variants: []\n    }","ref":"MyApp.Cldr.html#default_locale/0-example"},{"type":"function","title":"MyApp.Cldr.default_territory/0","doc":"Returns the default territory when a locale\ndoes not specify one and none can be inferred.","ref":"MyApp.Cldr.html#default_territory/0"},{"type":"function","title":"Example - MyApp.Cldr.default_territory/0","doc":"iex> MyApp.Cldr.default_territory()\n    :\"001\"","ref":"MyApp.Cldr.html#default_territory/0-example"},{"type":"function","title":"MyApp.Cldr.ellipsis/2","doc":"Add locale-specific ellipsis to a string.","ref":"MyApp.Cldr.html#ellipsis/2"},{"type":"function","title":"Arguments - MyApp.Cldr.ellipsis/2","doc":"* `string` is any `String.t` or a 2-element list\n  of `String.t` between which the ellipsis is inserted.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.\n\n* `options` is a keyword list of options","ref":"MyApp.Cldr.html#ellipsis/2-arguments"},{"type":"function","title":"Options - MyApp.Cldr.ellipsis/2","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`.\n\n* `:location` determines where to place the ellipsis. The options are\n  `:after` (the default for a single string argument), `:between`\n  (the default and only valid location for an argument that is a list\n  of two strings) and `:before`.\n\n* `:format` formats based upon whether the ellipsis\n  is inserted between words or sentences. The valid options are\n  `:word` or `:sentence`. The default is `:sentence`.","ref":"MyApp.Cldr.html#ellipsis/2-options"},{"type":"function","title":"Examples - MyApp.Cldr.ellipsis/2","doc":"iex> MyApp.Cldr.ellipsis \"And furthermore\"\n    \"And furthermore…\"\n\n    iex> MyApp.Cldr.ellipsis [\"And furthermore\", \"there is much to be done\"], locale: :ja\n    \"And furthermore…there is much to be done\"\n\n    iex> MyApp.Cldr.ellipsis \"And furthermore\", format: :word\n    \"And furthermore …\"\n\n    iex> MyApp.Cldr.ellipsis [\"And furthermore\", \"there is much to be done\"], locale: :ja, format: :word\n    \"And furthermore … there is much to be done\"","ref":"MyApp.Cldr.html#ellipsis/2-examples"},{"type":"function","title":"MyApp.Cldr.get_locale/0","doc":"Return the current locale to be used for `Cldr` functions that\ntake an optional locale parameter for which a locale is not supplied.","ref":"MyApp.Cldr.html#get_locale/0"},{"type":"function","title":"Example - MyApp.Cldr.get_locale/0","doc":"iex> MyApp.Cldr.put_locale(\"pl\")\n    iex> MyApp.Cldr.get_locale\n    %Cldr.LanguageTag{\n       backend: Elixir.MyApp.Cldr,\n       canonical_locale_name: \"pl\",\n       cldr_locale_name: :pl,\n       extensions: %{},\n       language: \"pl\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :pl,\n       territory: :PL,\n       requested_locale_name: \"pl\",\n       script: :Latn,\n       transform: %{},\n       language_variants: []\n     }","ref":"MyApp.Cldr.html#get_locale/0-example"},{"type":"function","title":"MyApp.Cldr.known_calendars/0","doc":"","ref":"MyApp.Cldr.html#known_calendars/0"},{"type":"function","title":"MyApp.Cldr.known_currencies/0","doc":"","ref":"MyApp.Cldr.html#known_currencies/0"},{"type":"function","title":"MyApp.Cldr.known_gettext_locale_name/1","doc":"Returns either the Gettext `locale_name` in Cldr format or\n`false` based upon whether the locale name is configured in\n`Gettext`.","ref":"MyApp.Cldr.html#known_gettext_locale_name/1"},{"type":"function","title":"Arguments - MyApp.Cldr.known_gettext_locale_name/1","doc":"* `locale` is any valid locale name returned by\n  `MyApp.Cldr.known_gettext_locale_names/0`","ref":"MyApp.Cldr.html#known_gettext_locale_name/1-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.known_gettext_locale_name/1","doc":"iex> MyApp.Cldr.known_gettext_locale_name \"en\"\n    \"en\"\n\n    iex> MyApp.Cldr.known_gettext_locale_name \"en-SA\"\n    false","ref":"MyApp.Cldr.html#known_gettext_locale_name/1-examples"},{"type":"function","title":"MyApp.Cldr.known_gettext_locale_name?/1","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Gettext.","ref":"MyApp.Cldr.html#known_gettext_locale_name?/1"},{"type":"function","title":"Arguments - MyApp.Cldr.known_gettext_locale_name?/1","doc":"* `locale` is any valid locale name returned by\n  `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.html#known_gettext_locale_name?/1-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.known_gettext_locale_name?/1","doc":"iex> MyApp.Cldr.known_gettext_locale_name?(\"en\")\n    true\n\n    iex> MyApp.Cldr.known_gettext_locale_name?(\"!!\")\n    false","ref":"MyApp.Cldr.html#known_gettext_locale_name?/1-examples"},{"type":"function","title":"MyApp.Cldr.known_gettext_locale_names/0","doc":"Returns a list of Gettext locale names but in CLDR format with\nunderscore replaced by hyphen in order to facilitate comparisons\nwith `Cldr` locale names.","ref":"MyApp.Cldr.html#known_gettext_locale_names/0"},{"type":"function","title":"MyApp.Cldr.known_locale_name/1","doc":"Returns either the `locale_name` or `false` based upon\nwhether the locale name is configured in `Cldr`.\n\nThis is helpful when building a list of `or` expressions\nto return the first known locale name from a list.","ref":"MyApp.Cldr.html#known_locale_name/1"},{"type":"function","title":"Arguments - MyApp.Cldr.known_locale_name/1","doc":"* `locale` is any valid locale name returned by\n  `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.html#known_locale_name/1-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.known_locale_name/1","doc":"iex> MyApp.Cldr.known_locale_name :\"en-AU\"\n    :\"en-AU\"\n\n    iex> MyApp.Cldr.known_locale_name :\"en-SA\"\n    false","ref":"MyApp.Cldr.html#known_locale_name/1-examples"},{"type":"function","title":"MyApp.Cldr.known_locale_name?/1","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Cldr.","ref":"MyApp.Cldr.html#known_locale_name?/1"},{"type":"function","title":"Arguments - MyApp.Cldr.known_locale_name?/1","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.html#known_locale_name?/1-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.known_locale_name?/1","doc":"iex> MyApp.Cldr.known_locale_name?(:en)\n    true\n\n    iex> MyApp.Cldr.known_locale_name?(:\"!!\")\n    false","ref":"MyApp.Cldr.html#known_locale_name?/1-examples"},{"type":"function","title":"MyApp.Cldr.known_locale_names/0","doc":"Returns a list of the known locale names.\n\nKnown locales are those locales which\nare the subset of all CLDR locales that\nhave been configured for use either\nin this module or in `Gettext`.","ref":"MyApp.Cldr.html#known_locale_names/0"},{"type":"function","title":"MyApp.Cldr.known_number_system_types/0","doc":"Returns a list of atoms representing the number systems types known to `Cldr`.","ref":"MyApp.Cldr.html#known_number_system_types/0"},{"type":"function","title":"Example - MyApp.Cldr.known_number_system_types/0","doc":"iex> MyApp.Cldr.known_number_system_types\n    [:default, :finance, :native, :traditional]","ref":"MyApp.Cldr.html#known_number_system_types/0-example"},{"type":"function","title":"MyApp.Cldr.known_number_systems/0","doc":"","ref":"MyApp.Cldr.html#known_number_systems/0"},{"type":"function","title":"MyApp.Cldr.known_rbnf_locale_name/1","doc":"Returns either the RBNF `locale_name` or `false` based upon\nwhether the locale name is configured in `Cldr`\nand has RBNF rules defined.","ref":"MyApp.Cldr.html#known_rbnf_locale_name/1"},{"type":"function","title":"Arguments - MyApp.Cldr.known_rbnf_locale_name/1","doc":"* `locale` is any valid locale name returned by\n  `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.html#known_rbnf_locale_name/1-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.known_rbnf_locale_name/1","doc":"iex> MyApp.Cldr.known_rbnf_locale_name :en\n    :en\n\n    iex> MyApp.Cldr.known_rbnf_locale_name :\"en-SA\"\n    false","ref":"MyApp.Cldr.html#known_rbnf_locale_name/1-examples"},{"type":"function","title":"MyApp.Cldr.known_rbnf_locale_name?/1","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Cldr and supports\nrules based number formats (RBNF).","ref":"MyApp.Cldr.html#known_rbnf_locale_name?/1"},{"type":"function","title":"Arguments - MyApp.Cldr.known_rbnf_locale_name?/1","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.html#known_rbnf_locale_name?/1-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.known_rbnf_locale_name?/1","doc":"iex> MyApp.Cldr.known_rbnf_locale_name?(:en)\n    true\n\n    iex> MyApp.Cldr.known_rbnf_locale_name?(:\"!!\")\n    false","ref":"MyApp.Cldr.html#known_rbnf_locale_name?/1-examples"},{"type":"function","title":"MyApp.Cldr.known_rbnf_locale_names/0","doc":"Returns a list of locale names which have rules-based number\nformats (RBNF).","ref":"MyApp.Cldr.html#known_rbnf_locale_names/0"},{"type":"function","title":"MyApp.Cldr.known_territories/0","doc":"","ref":"MyApp.Cldr.html#known_territories/0"},{"type":"function","title":"MyApp.Cldr.normalize_lenient_parse/3","doc":"Normalizes a string by applying transliteration\nof common symbols in numbers, currencies and dates","ref":"MyApp.Cldr.html#normalize_lenient_parse/3"},{"type":"function","title":"MyApp.Cldr.put_locale/1","doc":"Set the current locale to be used for `Cldr` functions that\ntake an optional locale parameter for which a locale is not supplied.","ref":"MyApp.Cldr.html#put_locale/1"},{"type":"function","title":"Arguments - MyApp.Cldr.put_locale/1","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `t:Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`\n\nSee [rfc5646](https://tools.ietf.org/html/rfc5646) for the specification\nof a language tag.","ref":"MyApp.Cldr.html#put_locale/1-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.put_locale/1","doc":"iex> MyApp.Cldr.put_locale(\"en\")\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: MyApp.Cldr,\n       canonical_locale_name: \"en\",\n       cldr_locale_name: :en,\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: \"en\",\n       language: \"en\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :en,\n       requested_locale_name: \"en\",\n       script: :Latn,\n       territory: :US,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> MyApp.Cldr.put_locale(\"invalid-locale!\")\n    {:error, {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"!\\\" starting at position 15\"}}","ref":"MyApp.Cldr.html#put_locale/1-examples"},{"type":"function","title":"MyApp.Cldr.quote/2","doc":"Add locale-specific quotation marks around a string.","ref":"MyApp.Cldr.html#quote/2"},{"type":"function","title":"Arguments - MyApp.Cldr.quote/2","doc":"* `string` is any valid Elixir string\n\n* `options` is a keyword list of options","ref":"MyApp.Cldr.html#quote/2-arguments"},{"type":"function","title":"Options - MyApp.Cldr.quote/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`","ref":"MyApp.Cldr.html#quote/2-options"},{"type":"function","title":"Examples - MyApp.Cldr.quote/2","doc":"iex> MyApp.Cldr.quote \"Quoted String\"\n    \"“Quoted String”\"\n\n    iex> MyApp.Cldr.quote \"Quoted String\", locale: :ja\n    \"「Quoted String」\"","ref":"MyApp.Cldr.html#quote/2-examples"},{"type":"function","title":"MyApp.Cldr.unknown_locale_names/0","doc":"Returns a list of the locales names that are configured,\nbut not known in CLDR.\n\nSince there is a compile-time exception raised if there are\nany unknown locales this function should always\nreturn an empty list.","ref":"MyApp.Cldr.html#unknown_locale_names/0"},{"type":"function","title":"MyApp.Cldr.validate_calendar/1","doc":"","ref":"MyApp.Cldr.html#validate_calendar/1"},{"type":"function","title":"MyApp.Cldr.validate_currency/1","doc":"","ref":"MyApp.Cldr.html#validate_currency/1"},{"type":"function","title":"MyApp.Cldr.validate_locale/1","doc":"Normalise and validate a locale name.","ref":"MyApp.Cldr.html#validate_locale/1"},{"type":"function","title":"Arguments - MyApp.Cldr.validate_locale/1","doc":"* `locale` is any valid locale name returned by `MyApp.Cldr.known_locale_names/0`\n  or a `Cldr.LanguageTag` struct returned by `MyApp.Cldr.Locale.new!/1`","ref":"MyApp.Cldr.html#validate_locale/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.validate_locale/1","doc":"* `{:ok, language_tag}`\n\n* `{:error, reason}`","ref":"MyApp.Cldr.html#validate_locale/1-returns"},{"type":"function","title":"Notes - MyApp.Cldr.validate_locale/1","doc":"See [rfc5646](https://tools.ietf.org/html/rfc5646) for the specification\nof a language tag.","ref":"MyApp.Cldr.html#validate_locale/1-notes"},{"type":"function","title":"Examples - MyApp.Cldr.validate_locale/1","doc":"iex> MyApp.Cldr.validate_locale(:en)\n    {:ok,\n    %Cldr.LanguageTag{\n      backend: MyApp.Cldr,\n      canonical_locale_name: \"en\",\n      cldr_locale_name: :en,\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en\",\n      script: :Latn,\n      territory: :US,\n      transform: %{},\n      language_variants: []\n    }}\n\n\n    iex> MyApp.Cldr.validate_locale MyApp.Cldr.default_locale()\n    {:ok,\n    %Cldr.LanguageTag{\n      backend: MyApp.Cldr,\n      canonical_locale_name: \"en-001\",\n      cldr_locale_name: :\"en-001\",\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-001\",\n      script: :Latn,\n      territory: :\"001\",\n      transform: %{},\n      language_variants: []\n    }}\n\n    iex> MyApp.Cldr.validate_locale(\"zzz\")\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}","ref":"MyApp.Cldr.html#validate_locale/1-examples"},{"type":"function","title":"MyApp.Cldr.validate_number_system/1","doc":"","ref":"MyApp.Cldr.html#validate_number_system/1"},{"type":"function","title":"MyApp.Cldr.validate_number_system_type/1","doc":"Normalise and validate a number system type.","ref":"MyApp.Cldr.html#validate_number_system_type/1"},{"type":"function","title":"Arguments - MyApp.Cldr.validate_number_system_type/1","doc":"* `number_system_type` is any number system type returned by\n  `Cldr.known_number_system_types/1`","ref":"MyApp.Cldr.html#validate_number_system_type/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.validate_number_system_type/1","doc":"* `{:ok, normalized_number_system_type}` or\n\n* `{:error, {exception, message}}`","ref":"MyApp.Cldr.html#validate_number_system_type/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.validate_number_system_type/1","doc":"iex> MyApp.Cldr.validate_number_system_type :default\n    {:ok, :default}\n\n    iex> MyApp.Cldr.validate_number_system_type :traditional\n    {:ok, :traditional}\n\n    iex> MyApp.Cldr.validate_number_system_type :latn\n    {\n      :error,\n      {Cldr.UnknownNumberSystemTypeError, \"The number system type :latn is unknown\"}\n    }\n\n    iex> MyApp.Cldr.validate_number_system_type \"bork\"\n    {\n      :error,\n      {Cldr.UnknownNumberSystemTypeError, \"The number system type \\\"bork\\\" is invalid\"}\n    }","ref":"MyApp.Cldr.html#validate_number_system_type/1-examples"},{"type":"function","title":"MyApp.Cldr.validate_territory/1","doc":"","ref":"MyApp.Cldr.html#validate_territory/1"},{"type":"function","title":"MyApp.Cldr.with_locale/2","doc":"Execute a function with a locale ensuring that the\ncurrent locale is restored after the function.","ref":"MyApp.Cldr.html#with_locale/2"},{"type":"function","title":"Arguments - MyApp.Cldr.with_locale/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n\n* `fun` is any 0-arity function or function capture.","ref":"MyApp.Cldr.html#with_locale/2-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.with_locale/2","doc":"* The value returned by the function `fun/0` or\n\n* `{:error, {exception, reason}}` if the locale is invalid or\n\n* raises an exception if the current locale cannot be\n  identified.","ref":"MyApp.Cldr.html#with_locale/2-returns"},{"type":"module","title":"MyApp.Cldr.AcceptLanguage","doc":"Parses HTTP `Accept-Language` header values as defined in\n[rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4).\n\nThe Accept-Language request-header field is similar to Accept, but restricts\nthe set of natural languages that are preferred as a response to the request.\nLanguage tags function are provided in `Cldr.LanguageTag`.\n\nThe format of an `Accept-Language` header is as follows in `ABNF` format:\n\n       Accept-Language = \"Accept-Language\" \":\"\n                         1#( language-range [ \";\" \"q\" \"=\" qvalue ] )\n       language-range  = ( ( 1*8ALPHA *( \"-\" 1*8ALPHA ) ) | \"*\" )\n\nEach language-range MAY be given an associated quality value which represents an\nestimate of the user's preference for the languages specified by that range. The\nquality value defaults to \"q=1\". For example,\n\n       Accept-Language: da, en-gb;q=0.8, en;q=0.7\n\nwould mean: \"I prefer Danish, but will accept British English and other types of English.\"","ref":"MyApp.Cldr.AcceptLanguage.html"},{"type":"function","title":"MyApp.Cldr.AcceptLanguage.best_match/1","doc":"Parse an `Accept-Language` string and return the best match for\na configured `Cldr` locale.","ref":"MyApp.Cldr.AcceptLanguage.html#best_match/1"},{"type":"function","title":"Arguments - MyApp.Cldr.AcceptLanguage.best_match/1","doc":"* `accept_langauge` is a string representing an accept language header","ref":"MyApp.Cldr.AcceptLanguage.html#best_match/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.AcceptLanguage.best_match/1","doc":"* `{:ok, language_tag}` or\n\n* `{:error, reason}`","ref":"MyApp.Cldr.AcceptLanguage.html#best_match/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.AcceptLanguage.best_match/1","doc":"iex> MyApp.Cldr.AcceptLanguage.best_match(\"da;q=0.1,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"zh-TW\",\n       cldr_locale_name: :\"zh-Hant\",\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: nil,\n       language: \"zh\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :\"zh-Hant\",\n       requested_locale_name: \"zh-TW\",\n       script: :Hant,\n       territory: :TW,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> MyApp.Cldr.AcceptLanguage.best_match(\"da;q=0.1,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"zh-TW\",\n       cldr_locale_name: :\"zh-Hant\",\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: nil,\n       language: \"zh\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :\"zh-Hant\",\n       requested_locale_name: \"zh-TW\",\n       script: :Hant,\n       territory: :TW,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> MyApp.Cldr.AcceptLanguage.best_match(\"xx,yy;q=0.3\")\n    {:error,\n     {Cldr.NoMatchingLocale,\n      \"No configured locale could be matched to \\\"xx,yy;q=0.3\\\"\"}}\n\n    iex> MyApp.Cldr.AcceptLanguage.best_match(\"invalid_tag\")\n    {:error, {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}","ref":"MyApp.Cldr.AcceptLanguage.html#best_match/1-examples"},{"type":"function","title":"MyApp.Cldr.AcceptLanguage.parse/1","doc":"Parses an `Accept-Language` header value in its string\nor tokenized form to return a tuple of the form\n`{:ok, [{quality, %Cldr.LanguageTag{}}, ...]}` sorted by quality.","ref":"MyApp.Cldr.AcceptLanguage.html#parse/1"},{"type":"function","title":"Arguments - MyApp.Cldr.AcceptLanguage.parse/1","doc":"* `accept-language` is any string in the format defined by\n  [rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"MyApp.Cldr.AcceptLanguage.html#parse/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.AcceptLanguage.parse/1","doc":"* `{:ok, [{quality, language_tag}, ...]}` or\n\n* `{:error, {Cldr.AcceptLanguageError, String.t}}`\n\nIf at least one valid language tag is found but errors are also\ndetected on one more more tags, an `{ok, list}` tuple is returned\nwuth an error tuple for each invalid tag added at the end of the list.","ref":"MyApp.Cldr.AcceptLanguage.html#parse/1-returns"},{"type":"function","title":"Example - MyApp.Cldr.AcceptLanguage.parse/1","doc":"iex> Cldr.AcceptLanguage.parse(\"da,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     [\n       {1.0,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"da\",\n          cldr_locale_name: :da,\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"da\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :da,\n          requested_locale_name: \"da\",\n          script: :Latn,\n          territory: :DK,\n          transform: %{},\n          language_variants: []\n        }},\n       {0.3,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"zh-TW\",\n          cldr_locale_name: :\"zh-Hant\",\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"zh\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :\"zh-Hant\",\n          requested_locale_name: \"zh-TW\",\n          script: :Hant,\n          territory: :TW,\n          transform: %{},\n          language_variants: []\n        }}\n     ]}\n\n    iex> MyApp.Cldr.AcceptLanguage.parse(\"invalid_tag\")\n    {:error,\n     {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n\n    iex> MyApp.Cldr.AcceptLanguage.parse(\"da,zh-TW;q=0.3,invalid_tag\")\n    {:ok,\n     [\n       {1.0,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"da\",\n          cldr_locale_name: :da,\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"da\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :da,\n          requested_locale_name: \"da\",\n          script: :Latn,\n          territory: :DK,\n          transform: %{},\n          language_variants: []\n        }},\n       {0.3,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"zh-TW\",\n          cldr_locale_name: :\"zh-Hant\",\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"zh\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :\"zh-Hant\",\n          requested_locale_name: \"zh-TW\",\n          script: :Hant,\n          territory: :TW,\n          transform: %{},\n          language_variants: []\n        }},\n       {:error,\n        {Cldr.LanguageTag.ParseError,\n         \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n     ]}","ref":"MyApp.Cldr.AcceptLanguage.html#parse/1-example"},{"type":"function","title":"MyApp.Cldr.AcceptLanguage.parse!/1","doc":"Parses an `Accept-Language` header value in its string\nor tokenized form to produce a list of tuples of the form\n`[{quality, %Cldr.LanguageTag{}}, ...]` sorted by quality\nin descending order.","ref":"MyApp.Cldr.AcceptLanguage.html#parse!/1"},{"type":"function","title":"Arguments - MyApp.Cldr.AcceptLanguage.parse!/1","doc":"* `accept-language` is any string in the format defined by [rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)","ref":"MyApp.Cldr.AcceptLanguage.html#parse!/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.AcceptLanguage.parse!/1","doc":"* `{:ok, [{quality, language_tag}, ...]}` or\n\n* raises a `Cldr.AcceptLanguageError` exception\n\nIf at least one valid language tag is found but errors are also\ndetected on one more more tags, an `{ok, list}` tuple is returned\nwuth an error tuple for each invalid tag added at the end of the list.","ref":"MyApp.Cldr.AcceptLanguage.html#parse!/1-returns"},{"type":"function","title":"Example - MyApp.Cldr.AcceptLanguage.parse!/1","doc":"iex> MyApp.Cldr.AcceptLanguage.parse!(\"da,zh-TW;q=0.3\")\n    [\n      {1.0,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"da\",\n         cldr_locale_name: :da,\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"da\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :da,\n         requested_locale_name: \"da\",\n         script: :Latn,\n         territory: :DK,\n         transform: %{},\n         language_variants: []\n       }},\n      {0.3,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"zh-TW\",\n         cldr_locale_name: :\"zh-Hant\",\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"zh\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :\"zh-Hant\",\n         requested_locale_name: \"zh-TW\",\n         script: :Hant,\n         territory: :TW,\n         transform: %{},\n         language_variants: []\n       }}\n    ]\n\n    MyApp.Cldr.AcceptLanguage.parse! \"invalid_tag\"\n    ** (Cldr.AcceptLanguageError) \"Expected a BCP47 language tag. Could not parse the remaining \"g\" starting at position 11\n        (ex_cldr) lib/cldr/accept_language.ex:304: Cldr.AcceptLanguage.parse!/1\n\n    iex> MyApp.Cldr.AcceptLanguage.parse!(\"da,zh-TW;q=0.3,invalid_tag\")\n    [\n      {1.0,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"da\",\n         cldr_locale_name: :da,\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"da\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :da,\n         requested_locale_name: \"da\",\n         script: :Latn,\n         territory: :DK,\n         transform: %{},\n         language_variants: []\n       }},\n      {0.3,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"zh-TW\",\n         cldr_locale_name: :\"zh-Hant\",\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"zh\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :\"zh-Hant\",\n         requested_locale_name: \"zh-TW\",\n         script: :Hant,\n         territory: :TW,\n         transform: %{},\n         language_variants: []\n       }},\n      {:error,\n       {Cldr.LanguageTag.ParseError,\n        \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n    ]","ref":"MyApp.Cldr.AcceptLanguage.html#parse!/1-example"},{"type":"module","title":"MyApp.Cldr.Locale","doc":"Backend module that provides functions\nto define new locales and display human-readable\nlocale names for presentation purposes.","ref":"MyApp.Cldr.Locale.html"},{"type":"function","title":"MyApp.Cldr.Locale.fallback_locale_names/1","doc":"Returns the list of fallback locale names, starting\nwith the provided locale name.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale..","ref":"MyApp.Cldr.Locale.html#fallback_locale_names/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.fallback_locale_names/1","doc":"* `locale_name` is any locale name returned by\n  `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.Locale.html#fallback_locale_names/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.fallback_locale_names/1","doc":"* `{:ok, list_of_locale_names}` or\n\n* `{:error, {exception, reason}}`","ref":"MyApp.Cldr.Locale.html#fallback_locale_names/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.fallback_locale_names/1","doc":"iex> MyApp.Cldr.Locale.fallback_locale_names(:\"fr-CA\")\n    {:ok, [:\"fr-CA\", :fr, :und]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    iex> MyApp.Cldr.Locale.fallback_locale_names(:nb)\n    {:ok, [:nb, :no, :und]}","ref":"MyApp.Cldr.Locale.html#fallback_locale_names/1-examples"},{"type":"function","title":"MyApp.Cldr.Locale.fallback_locales/1","doc":"Returns the list of fallback locales, starting\nwith the provided locale name.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale.","ref":"MyApp.Cldr.Locale.html#fallback_locales/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.fallback_locales/1","doc":"* `locale_name` is any locale name returned by\n  `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.Locale.html#fallback_locales/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.fallback_locales/1","doc":"* `{:ok, list_of_locales}` or\n\n* `{:error, {exception, reason}}`","ref":"MyApp.Cldr.Locale.html#fallback_locales/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.fallback_locales/1","doc":"MyApp.Cldr.Locale.fallback_locales(:\"fr-CA\")\n    => {:ok,\n         [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n          #Cldr.LanguageTag ]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    MyApp.Cldr.Locale.fallback_locales(:nb))\n    => {:ok,\n         [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n          #Cldr.LanguageTag ]}","ref":"MyApp.Cldr.Locale.html#fallback_locales/1-examples"},{"type":"function","title":"MyApp.Cldr.Locale.locale_for_territory/1","doc":"Returns the \"best fit\" locale for a given territory.\n\nUsing the population percentage data from CLDR, the\nlanguage most commonly spoken in the given territory\nis used to form a locale name which is then validated\nagainst the given backend.\n\nFirst a territory-specific locale is validated and if\nthat fails, the base language only is validate.\n\nFor example, if the territory is `AU` then then the\nlanguage most spoken is \"en\". First, the locale \"en-AU\"\nis validated and if that fails, \"en\" is validated.","ref":"MyApp.Cldr.Locale.html#locale_for_territory/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.locale_for_territory/1","doc":"* `territory` is any ISO 3166 Alpha-2 territory\n  code that can be validated by `Cldr.validate_territory/1`","ref":"MyApp.Cldr.Locale.html#locale_for_territory/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.locale_for_territory/1","doc":"* `{:ok, language_tag}` or\n\n* `{:error, {exception, reason}}`","ref":"MyApp.Cldr.Locale.html#locale_for_territory/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.locale_for_territory/1","doc":"iex> MyApp.Cldr.Locale.locale_for_territory(:AU)\n  Elixir.MyApp.Cldr.validate_locale(:\"en-AU\")\n\n  iex> MyApp.Cldr.Locale.locale_for_territory(:US)\n  Elixir.MyApp.Cldr.validate_locale(:\"en-US\")\n\n  iex> MyApp.Cldr.Locale.locale_for_territory(:ZZ)\n  {:error, {Cldr.UnknownTerritoryError, \"The territory :ZZ is unknown\"}}","ref":"MyApp.Cldr.Locale.html#locale_for_territory/1-examples"},{"type":"function","title":"MyApp.Cldr.Locale.locale_from_host/2","doc":"Returns a \"best fit\" locale for a host name.","ref":"MyApp.Cldr.Locale.html#locale_from_host/2"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.locale_from_host/2","doc":"* `host` is any valid host name\n\n* `options` is a keyword list of options. The default\n  is `[]`.","ref":"MyApp.Cldr.Locale.html#locale_from_host/2-arguments"},{"type":"function","title":"Options - MyApp.Cldr.Locale.locale_from_host/2","doc":"* `:tlds` is a list of territory codes as upper-cased\n  atoms that are to be considered as top-level domains.\n  See `Cldr.Locale.locale_from_host/2` for the default\n  list.","ref":"MyApp.Cldr.Locale.html#locale_from_host/2-options"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.locale_from_host/2","doc":"* `{:ok, langauge_tag}` or\n\n* `{:error, {exception, reason}}`","ref":"MyApp.Cldr.Locale.html#locale_from_host/2-returns"},{"type":"function","title":"Notes - MyApp.Cldr.Locale.locale_from_host/2","doc":"Certain top-level domains have become associated with content\nunderlated to the territory for who the domain is registered.\nTherefore Google (and perhaps others) do not associate these\nTLDs as belonging to the territory but rather are considered\ngeneric top-level domain names.","ref":"MyApp.Cldr.Locale.html#locale_from_host/2-notes"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.locale_from_host/2","doc":"iex> MyApp.Cldr.Locale.locale_from_host \"a.b.com.au\"\n    Elixir.MyApp.Cldr.validate_locale(:\"en-AU\")\n\n    iex> MyApp.Cldr.Locale.locale_from_host(\"a.b.com.tv\")\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"tv\\\"\"}}\n\n    iex> MyApp.Cldr.Locale.locale_from_host(\"a.b.com\")\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"com\\\"\"}}","ref":"MyApp.Cldr.Locale.html#locale_from_host/2-examples"},{"type":"function","title":"MyApp.Cldr.Locale.new/1","doc":"","ref":"MyApp.Cldr.Locale.html#new/1"},{"type":"function","title":"MyApp.Cldr.Locale.new!/1","doc":"","ref":"MyApp.Cldr.Locale.html#new!/1"},{"type":"function","title":"MyApp.Cldr.Locale.script_direction_from_locale/1","doc":"Returns the script direction for a locale.","ref":"MyApp.Cldr.Locale.html#script_direction_from_locale/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.script_direction_from_locale/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`.","ref":"MyApp.Cldr.Locale.html#script_direction_from_locale/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.script_direction_from_locale/1","doc":"* The script direction which is either `:ltr` (for left-to-right\n  scripts) or `:rtl` (for right-to-left scripts).","ref":"MyApp.Cldr.Locale.html#script_direction_from_locale/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.script_direction_from_locale/1","doc":"iex> MyApp.Cldr.Locale.script_direction_from_locale \"en-US\"\n    :ltr\n\n    iex> MyApp.Cldr.Locale.script_direction_from_locale :ar\n    :rtl","ref":"MyApp.Cldr.Locale.html#script_direction_from_locale/1-examples"},{"type":"function","title":"MyApp.Cldr.Locale.territory_from_host/1","doc":"Returns the last segment of a host that might\nbe a territory.","ref":"MyApp.Cldr.Locale.html#territory_from_host/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.territory_from_host/1","doc":"* `host` is any valid host name","ref":"MyApp.Cldr.Locale.html#territory_from_host/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.territory_from_host/1","doc":"* `{:ok, territory}` or\n\n* `{:error, {exception, reason}}`","ref":"MyApp.Cldr.Locale.html#territory_from_host/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.territory_from_host/1","doc":"iex> Cldr.Locale.territory_from_host(\"a.b.com.au\")\n    {:ok, :AU}\n\n    iex> Cldr.Locale.territory_from_host(\"a.b.com\")\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"com\\\"\"}}","ref":"MyApp.Cldr.Locale.html#territory_from_host/1-examples"},{"type":"function","title":"MyApp.Cldr.Locale.territory_from_locale/1","doc":"Returns the territory from a language tag or\nlocale name.","ref":"MyApp.Cldr.Locale.html#territory_from_locale/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.territory_from_locale/1","doc":"* `locale` is any language tag returned by\n  `MyApp.Cldr.Locale.new/1`\n  or a locale name in the list returned by\n  `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.Locale.html#territory_from_locale/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.territory_from_locale/1","doc":"* A territory code as an atom","ref":"MyApp.Cldr.Locale.html#territory_from_locale/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.territory_from_locale/1","doc":"iex> MyApp.Cldr.Locale.territory_from_locale \"en-US\"\n    :US\n\n    iex> MyApp.Cldr.Locale.territory_from_locale \"en-US-u-rg-GBzzzz\"\n    :GB","ref":"MyApp.Cldr.Locale.html#territory_from_locale/1-examples"},{"type":"function","title":"MyApp.Cldr.Locale.timezone_from_locale/1","doc":"Returns the time zone from a language tag or\nlocale name.","ref":"MyApp.Cldr.Locale.html#timezone_from_locale/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Locale.timezone_from_locale/1","doc":"* `locale` is any language tag returned by\n  `MyApp.Cldr.Locale.new/1`\n  or a locale name in the list returned by\n  `MyApp.Cldr.known_locale_names/0`","ref":"MyApp.Cldr.Locale.html#timezone_from_locale/1-arguments"},{"type":"function","title":"Returns - MyApp.Cldr.Locale.timezone_from_locale/1","doc":"* A time zone ID as a string or\n\n* `:error` if no time zone can be determined","ref":"MyApp.Cldr.Locale.html#timezone_from_locale/1-returns"},{"type":"function","title":"Examples - MyApp.Cldr.Locale.timezone_from_locale/1","doc":"iex> MyApp.Cldr.Locale.timezone_from_locale \"en-US-u-tz-ausyd\"\n    \"Australia/Sydney\"","ref":"MyApp.Cldr.Locale.html#timezone_from_locale/1-examples"},{"type":"module","title":"MyApp.Cldr.Number.Cardinal","doc":"Implements cardinal plural rules for numbers.","ref":"MyApp.Cldr.Number.Cardinal.html"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.available_locale_names/0","doc":"The locale names for which plural rules are defined.","ref":"MyApp.Cldr.Number.Cardinal.html#available_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.known_locale_names/0","doc":"The configured locales for which plural rules are defined.\n\nReturns the intersection of `MyApp.Cldr.known_locale_names/0` and\nthe locales for which Cardinal plural rules are defined.\n\nThere are many `Cldr` locales which don't have their own plural\nrules so this list is the intersection of `Cldr`'s configured\nlocales and those that have rules.","ref":"MyApp.Cldr.Number.Cardinal.html#known_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.plural_rule/3","doc":"Return the plural key for a given number in a given locale\n\nReturns which plural key (`:zero`, `:one`, `:two`, `:few`,\n`:many` or `:other`) a given number fits into within the\ncontext of a given locale.\n\nNote that these key names should not be interpreted\nliterally.  For example, the key returned from\n`Cldr.Number.Ordinal.plural_rule(0, \"en\")` is actually\n`:other`, not `:zero`.\n\nThis key can then be used to format a number, date, time, unit,\nlist or other content in a plural-sensitive way.","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rule/3"},{"type":"function","title":"Arguments - MyApp.Cldr.Number.Cardinal.plural_rule/3","doc":"* `number` is any `integer`, `float` or `Decimal`\n\n* `locale` is any locale returned by `Cldr.Locale.new!/2` or any\n  `locale_name` returned by `MyApp.Cldr.known_locale_names/0`\n\n* `rounding` is one of `[:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down]`.  The\n  default is `:half_even`.","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rule/3-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.Number.Cardinal.plural_rule/3","doc":"iex> MyApp.Cldr.Number.Cardinal.plural_rule 0, \"fr\"\n    :one\n\n    iex> MyApp.Cldr.Number.Cardinal.plural_rule 0, \"en\"\n    :other","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rule/3-examples"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.plural_rules/0","doc":"Returns all the plural rules defined in CLDR.","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rules/0"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.plural_rules_for/1","doc":"Return the plural rules for a locale.","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rules_for/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Number.Cardinal.plural_rules_for/1","doc":"* `locale` is any locale returned by `MyApp.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `MyApp.Cldr.known_locale_names/0`\n\nThe rules are returned in AST form after parsing.","ref":"MyApp.Cldr.Number.Cardinal.html#plural_rules_for/1-arguments"},{"type":"function","title":"MyApp.Cldr.Number.Cardinal.pluralize/3","doc":"Pluralize a number using cardinal plural rules\nand a substitution map.","ref":"MyApp.Cldr.Number.Cardinal.html#pluralize/3"},{"type":"function","title":"Arguments - MyApp.Cldr.Number.Cardinal.pluralize/3","doc":"* `number` is an integer, float or Decimal\n\n* `locale` is any locale returned by `MyApp.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `MyApp.Cldr.known_locale_names/0`\n\n* `substitutions` is a map that maps plural keys to a string.\n  The valid substitution keys are `:zero`, `:one`, `:two`,\n  `:few`, `:many` and `:other`.\n\nSee also `MyApp.Cldr.Number.Cardinal.Cardinal.plural_rule/3`.","ref":"MyApp.Cldr.Number.Cardinal.html#pluralize/3-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.Number.Cardinal.pluralize/3","doc":"iex> MyApp.Cldr.Number.Cardinal.pluralize 1, \"en\", %{one: \"one\"}\n    \"one\"\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize 2, \"en\", %{one: \"one\"}\n    nil\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize 2, \"en\", %{one: \"one\", two: \"two\", other: \"other\"}\n    \"other\"\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize 22, \"en\", %{one: \"one\", two: \"two\", other: \"other\"}\n    \"other\"\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize Decimal.new(1), \"en\", %{one: \"one\"}\n    \"one\"\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize Decimal.new(2), \"en\", %{one: \"one\"}\n    nil\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize Decimal.new(2), \"en\", %{one: \"one\", two: \"two\"}\n    nil\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize 1..10, \"ar\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"few\"\n\n    iex> MyApp.Cldr.Number.Cardinal.pluralize 1..10, \"en\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"other\"","ref":"MyApp.Cldr.Number.Cardinal.html#pluralize/3-examples"},{"type":"module","title":"MyApp.Cldr.Number.Ordinal","doc":"Implements ordinal plural rules for numbers.","ref":"MyApp.Cldr.Number.Ordinal.html"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.available_locale_names/0","doc":"The locale names for which plural rules are defined.","ref":"MyApp.Cldr.Number.Ordinal.html#available_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.known_locale_names/0","doc":"The configured locales for which plural rules are defined.\n\nReturns the intersection of `MyApp.Cldr.known_locale_names/0` and\nthe locales for which Ordinal plural rules are defined.\n\nThere are many `Cldr` locales which don't have their own plural\nrules so this list is the intersection of `Cldr`'s configured\nlocales and those that have rules.","ref":"MyApp.Cldr.Number.Ordinal.html#known_locale_names/0"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.plural_rule/3","doc":"Return the plural key for a given number in a given locale\n\nReturns which plural key (`:zero`, `:one`, `:two`, `:few`,\n`:many` or `:other`) a given number fits into within the\ncontext of a given locale.\n\nNote that these key names should not be interpreted\nliterally.  For example, the key returned from\n`Cldr.Number.Ordinal.plural_rule(0, \"en\")` is actually\n`:other`, not `:zero`.\n\nThis key can then be used to format a number, date, time, unit,\nlist or other content in a plural-sensitive way.","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rule/3"},{"type":"function","title":"Arguments - MyApp.Cldr.Number.Ordinal.plural_rule/3","doc":"* `number` is any `integer`, `float` or `Decimal`\n\n* `locale` is any locale returned by `Cldr.Locale.new!/2` or any\n  `locale_name` returned by `MyApp.Cldr.known_locale_names/0`\n\n* `rounding` is one of `[:down, :up, :ceiling, :floor, :half_even, :half_up, :half_down]`.  The\n  default is `:half_even`.","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rule/3-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.Number.Ordinal.plural_rule/3","doc":"iex> MyApp.Cldr.Number.Ordinal.plural_rule 0, \"fr\"\n    :other\n\n    iex> MyApp.Cldr.Number.Ordinal.plural_rule 1, \"en\"\n    :one","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rule/3-examples"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.plural_rules/0","doc":"Returns all the plural rules defined in CLDR.","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rules/0"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.plural_rules_for/1","doc":"Return the plural rules for a locale.","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rules_for/1"},{"type":"function","title":"Arguments - MyApp.Cldr.Number.Ordinal.plural_rules_for/1","doc":"* `locale` is any locale returned by `MyApp.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `MyApp.Cldr.known_locale_names/0`\n\nThe rules are returned in AST form after parsing.","ref":"MyApp.Cldr.Number.Ordinal.html#plural_rules_for/1-arguments"},{"type":"function","title":"MyApp.Cldr.Number.Ordinal.pluralize/3","doc":"Pluralize a number using ordinal plural rules\nand a substitution map.","ref":"MyApp.Cldr.Number.Ordinal.html#pluralize/3"},{"type":"function","title":"Arguments - MyApp.Cldr.Number.Ordinal.pluralize/3","doc":"* `number` is an integer, float or Decimal or a `Range.t{}`.  When a range, The\n  is that in any usage, the start value is strictly less than the end value,\n  and that no values are negative. Results for any cases that do not meet\n  these criteria are undefined.\n\n* `locale` is any locale returned by `MyApp.Cldr.Locale.new!/1` or any\n  `locale_name` returned by `MyApp.Cldr.known_locale_names/0`\n\n* `substitutions` is a map that maps plural keys to a string.\n  The valid substitution keys are `:zero`, `:one`, `:two`,\n  `:few`, `:many` and `:other`.\n\nSee also `MyApp.Cldr.Number.Ordinal.Ordinal.plural_rule/3`.","ref":"MyApp.Cldr.Number.Ordinal.html#pluralize/3-arguments"},{"type":"function","title":"Examples - MyApp.Cldr.Number.Ordinal.pluralize/3","doc":"iex> MyApp.Cldr.Number.Ordinal.pluralize 1, :en, %{one: \"one\"}\n    \"one\"\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize 2, :en, %{one: \"one\"}\n    nil\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize 2, :en, %{one: \"one\", two: \"two\"}\n    \"two\"\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize 22, :en, %{one: \"one\", two: \"two\", other: \"other\"}\n    \"two\"\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize Decimal.new(1), :en, %{one: \"one\"}\n    \"one\"\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize Decimal.new(2), :en, %{one: \"one\"}\n    nil\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize Decimal.new(2), :en, %{one: \"one\", two: \"two\"}\n    \"two\"\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize 1..10, \"ar\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"other\"\n\n    iex> MyApp.Cldr.Number.Ordinal.pluralize 1..10, \"en\", %{one: \"one\", few: \"few\", other: \"other\"}\n    \"other\"","ref":"MyApp.Cldr.Number.Ordinal.html#pluralize/3-examples"},{"type":"module","title":"MyApp.Cldr.Number.PluralRule.Range","doc":"Implements plural rules for ranges","ref":"MyApp.Cldr.Number.PluralRule.Range.html"},{"type":"function","title":"MyApp.Cldr.Number.PluralRule.Range.plural_rule/3","doc":"Returns a final plural type for a start-of-range plural\ntype, an end-of-range plural type and a locale.","ref":"MyApp.Cldr.Number.PluralRule.Range.html#plural_rule/3"},{"type":"function","title":"Arguments - MyApp.Cldr.Number.PluralRule.Range.plural_rule/3","doc":"* `first` is a plural type for the start of a range\n\n* `last` is a plural type for the end of a range\n\n* `locale` is any `Cldr.LanguageTag.t` or a language name\n  (not locale name)","ref":"MyApp.Cldr.Number.PluralRule.Range.html#plural_rule/3-arguments"},{"type":"function","title":"Example - MyApp.Cldr.Number.PluralRule.Range.plural_rule/3","doc":"iex> MyApp.Cldr.Number.PluralRule.Range.plural_rule :other, :few, \"ar\"\n    :few","ref":"MyApp.Cldr.Number.PluralRule.Range.html#plural_rule/3-example"},{"type":"module","title":"Unicode.String","doc":"This module provides functions that implement some\nof the [Unicode](https://unicode.org) standards:\n\n* The [Unicode Case Mapping](https://www.unicode.org/versions/Unicode13.0.0/ch03.pdf) algorithm\n  to provide mapping to upper, lower and title case text.\n\n* The [Unicode Case Folding](https://www.unicode.org/versions/Unicode13.0.0/ch03.pdf) algorithm\n  to provide case-independent equality checking irrespective of language or script.\n\n* The [Unicode Segmentation](https://unicode.org/reports/tr29/) algorithm to detect,\n  break or splut strings into grapheme clusters, works and sentences.\n\n* The [Unicode Line Breaking](https://www.unicode.org/reports/tr14/) algorithm to determine\n  line breaks (as in word-wrapping).\n\n* The [Unicode Case Mapping](https://www.unicode.org/versions/Unicode13.0.0/ch03.pdf) algorithm\n  to provide mapping to upper, lower and title case text.","ref":"Unicode.String.html"},{"type":"function","title":"Unicode.String.break/2","doc":"Returns match data indicating if the\nrequested break is applicable\nat the point between the two string\nsegments represented by `{string_before, string_after}`.","ref":"Unicode.String.html#break/2"},{"type":"function","title":"Arguments - Unicode.String.break/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of\n  options.","ref":"Unicode.String.html#break/2-arguments"},{"type":"function","title":"Returns - Unicode.String.break/2","doc":"A tuple indicating if a break would\nbe applicable at this point between\n`string_before` and `string_after`.\n\n* `{:break, {string_before, {matched_string, remaining_string}}}` or\n\n* `{:no_break, {string_before, {matched_string, remaining_string}}}` or\n\n* `{:error, reason}`","ref":"Unicode.String.html#break/2-returns"},{"type":"function","title":"Options - Unicode.String.break/2","doc":"* `:locale` is any locale returned by\n  `Unicode.String.Segment.known_segmentation_locales/0`.\n  The default is \"root\" which corresponds\n  to the break rules defined by the\n  [Unicode Segmentation](https://unicode.org/reports/tr29/) rules.\n\n* `:break` is the type of break. It is one of\n  `:grapheme`, `:word`, `:line` or `:sentence`. The\n  default is `:word`.\n\n* `:suppressions` is a boolean which,\n  if `true`, will suppress breaks for common\n  abbreviations defined for the `locale`. The\n  default is `true`.","ref":"Unicode.String.html#break/2-options"},{"type":"function","title":"Examples - Unicode.String.break/2","doc":"iex> Unicode.String.break {\"This is \", \"some words\"}\n    {:break, {\"This is \", {\"s\", \"ome words\"}}}\n\n    iex> Unicode.String.break {\"This is \", \"some words\"}, break: :sentence\n    {:no_break, {\"This is \", {\"s\", \"ome words\"}}}\n\n    iex> Unicode.String.break {\"This is one. \", \"This is some words.\"}, break: :sentence\n    {:break, {\"This is one. \", {\"T\", \"his is some words.\"}}}","ref":"Unicode.String.html#break/2-examples"},{"type":"function","title":"Unicode.String.break?/2","doc":"Returns a boolean indicating if the\nrequested break is applicable\nat the point between the two string\nsegments represented by `{string_before, string_after}`.","ref":"Unicode.String.html#break?/2"},{"type":"function","title":"Arguments - Unicode.String.break?/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of\n  options.","ref":"Unicode.String.html#break?/2-arguments"},{"type":"function","title":"Returns - Unicode.String.break?/2","doc":"* `true` or `false` or\n\n* raises an exception if there is an error","ref":"Unicode.String.html#break?/2-returns"},{"type":"function","title":"Options - Unicode.String.break?/2","doc":"* `:locale` is any locale returned by\n  `Unicode.String.Segment.known_segmentation_locales/0`.\n  The default is \"root\" which corresponds\n  to the break rules defined by the\n  [Unicode Segmentation](https://unicode.org/reports/tr29/) rules.\n\n* `:break` is the type of break. It is one of\n  `:grapheme`, `:word`, `:line` or `:sentence`. The\n  default is `:word`.\n\n* `:suppressions` is a boolean which,\n  if `true`, will suppress breaks for common\n  abbreviations defined for the `locale`. The\n  default is `true`.","ref":"Unicode.String.html#break?/2-options"},{"type":"function","title":"Examples - Unicode.String.break?/2","doc":"iex> Unicode.String.break? {\"This is \", \"some words\"}\n    true\n\n    iex> Unicode.String.break? {\"This is \", \"some words\"}, break: :sentence\n    false\n\n    iex> Unicode.String.break? {\"This is one. \", \"This is some words.\"}, break: :sentence\n    true","ref":"Unicode.String.html#break?/2-examples"},{"type":"function","title":"Unicode.String.downcase/2","doc":"Converts all characters in the given string to lower case\naccording to the Unicode Casing algorithm.\n\n#","ref":"Unicode.String.html#downcase/2"},{"type":"function","title":"Arguments - Unicode.String.downcase/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of options.\n\n#","ref":"Unicode.String.html#downcase/2-arguments"},{"type":"function","title":"Options - Unicode.String.downcase/2","doc":"* `:locale` is any [ISO 639](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes)\n  language code or a [LanguageTag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html)\n  which provides integration with [ex_cldr](https://hex.pm/packages/ex_cldr)\n  applications.  The default is `:any` which signifies the\n  application of the base Unicode casing algorithm.\n\n#","ref":"Unicode.String.html#downcase/2-options"},{"type":"function","title":"Notes - Unicode.String.downcase/2","doc":"* The locale option determines the use of certain locale-specific\n  casing rules.  Where no specific casing rules apply to\n  the given locale, the base Unicode casing algorithm is\n  applied. The locales which have customized casing rules\n  are returned by `Unicode.String.special_casing_locales/0`.\n\n#","ref":"Unicode.String.html#downcase/2-notes"},{"type":"function","title":"Returns - Unicode.String.downcase/2","doc":"* `downcased_string`\n\n#","ref":"Unicode.String.html#downcase/2-returns"},{"type":"function","title":"Examples - Unicode.String.downcase/2","doc":"iex> Unicode.String.downcase(\"THE QUICK BROWN FOX\")\n    \"the quick brown fox\"\n\n    # Lower case Greek with a final sigma\n    iex> Unicode.String.downcase(\"ὈΔΥΣΣΕΎΣ\", locale: :el)\n    \"ὀδυσσεύς\"\n\n    # Lower case in Turkish and Azeri correctly handles\n    # undotted-i and undotted-I\n    iex> Unicode.String.downcase(\"DİYARBAKIR\", locale: :tr)\n    \"diyarbakır\"","ref":"Unicode.String.html#downcase/2-examples"},{"type":"function","title":"Unicode.String.equals_ignoring_case?/3","doc":"Compares two strings in a case insensitive\nmanner.\n\nCase folding is applied to the two string\narguments which are then compared with the\n`==` operator.","ref":"Unicode.String.html#equals_ignoring_case?/3"},{"type":"function","title":"Arguments - Unicode.String.equals_ignoring_case?/3","doc":"* `string_a` and `string_b` are two strings\n  to be compared","ref":"Unicode.String.html#equals_ignoring_case?/3-arguments"},{"type":"function","title":"Returns - Unicode.String.equals_ignoring_case?/3","doc":"* `true` or `false`","ref":"Unicode.String.html#equals_ignoring_case?/3-returns"},{"type":"function","title":"Notes - Unicode.String.equals_ignoring_case?/3","doc":"* This function applies the [Unicode Case Folding\n  algorithm](https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf)\n\n* The algorithm does not apply any treatment to diacritical\n  marks hence \"compare strings without accents\" is not\n  part of this function.\n\n* No string normalization is performed. Where the\n  normalization state of the string cannot be guaranteed\n  it is recommended they be normalized before comparison\n  using `String.normalize(string, :nfc)`.","ref":"Unicode.String.html#equals_ignoring_case?/3-notes"},{"type":"function","title":"Examples - Unicode.String.equals_ignoring_case?/3","doc":"iex> Unicode.String.equals_ignoring_case? \"ABC\", \"abc\"\n    true\n\n    iex> Unicode.String.equals_ignoring_case? \"beißen\", \"beissen\"\n    true\n\n    iex> Unicode.String.equals_ignoring_case? \"grüßen\", \"grussen\"\n    false","ref":"Unicode.String.html#equals_ignoring_case?/3-examples"},{"type":"function","title":"Unicode.String.find_matching_locale/3","doc":"","ref":"Unicode.String.html#find_matching_locale/3"},{"type":"function","title":"Unicode.String.fold/1","doc":"","ref":"Unicode.String.html#fold/1"},{"type":"function","title":"Unicode.String.fold/2","doc":"","ref":"Unicode.String.html#fold/2"},{"type":"function","title":"Unicode.String.next/2","doc":"Returns next segment in a string.","ref":"Unicode.String.html#next/2"},{"type":"function","title":"Arguments - Unicode.String.next/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of\n  options.","ref":"Unicode.String.html#next/2-arguments"},{"type":"function","title":"Returns - Unicode.String.next/2","doc":"A tuple with the segment and the remainder of the string or `\"\"`\nin case the String reached its end.\n\n* `{next_string, rest_of_the_string}` or\n\n* `{:error, reason}`","ref":"Unicode.String.html#next/2-returns"},{"type":"function","title":"Options - Unicode.String.next/2","doc":"* `:locale` is any locale returned by\n  `Unicode.String.Segment.known_segmentation_locales/0` or\n  a [Cldr.LanguageTag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html)\n  struct. The default is \"root\" which corresponds\n  to the break rules defined by the\n  [Unicode Segmentation](https://unicode.org/reports/tr29/) rules.\n\n* `:break` is the type of break. It is one of\n  `:grapheme`, `:word`, `:line` or `:sentence`. The\n  default is `:word`.\n\n* `:suppressions` is a boolean which,\n  if `true`, will suppress breaks for common\n  abbreviations defined for the `locale`. The\n  default is `true`.","ref":"Unicode.String.html#next/2-options"},{"type":"function","title":"Examples - Unicode.String.next/2","doc":"iex> Unicode.String.next \"This is a sentence. And another.\", break: :word\n    {\"This\", \" is a sentence. And another.\"}\n\n    iex> Unicode.String.next \"This is a sentence. And another.\", break: :sentence\n    {\"This is a sentence. \", \"And another.\"}","ref":"Unicode.String.html#next/2-examples"},{"type":"function","title":"Unicode.String.special_casing_locales/0","doc":"Returms a list of locales that have special\ncasing rules.\n\n#","ref":"Unicode.String.html#special_casing_locales/0"},{"type":"function","title":"Example - Unicode.String.special_casing_locales/0","doc":"iex> Unicode.String.special_casing_locales()\n    [:az, :el, :lt, :nl, :tr]","ref":"Unicode.String.html#special_casing_locales/0-example"},{"type":"function","title":"Unicode.String.split/2","doc":"Splits a string according to the\nspecified break type.","ref":"Unicode.String.html#split/2"},{"type":"function","title":"Arguments - Unicode.String.split/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of\n  options.","ref":"Unicode.String.html#split/2-arguments"},{"type":"function","title":"Returns - Unicode.String.split/2","doc":"* A list of strings after applying the\n  specified break rules or\n\n* `{:error, reason}`","ref":"Unicode.String.html#split/2-returns"},{"type":"function","title":"Options - Unicode.String.split/2","doc":"* `:locale` is any locale returned by\n  `Unicode.String.Segment.known_segmentation_locales/0` or\n  a [Cldr.LanguageTag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html)\n  struct. The default is \"root\" which corresponds\n  to the break rules defined by the\n  [Unicode Segmentation](https://unicode.org/reports/tr29/) rules.\n\n* `:break` is the type of break. It is one of\n  `:grapheme`, `:word`, `:line` or `:sentence`. The\n  default is `:word`.\n\n* `:suppressions` is a boolean which,\n  if `true`, will suppress breaks for common\n  abbreviations defined for the `locale`. The\n  default is `true`.\n\n* `:trim` is a boolean indicating if segments\n  the are comprised of only white space are to be\n  excluded from the returned list.  The default\n  is `false`.","ref":"Unicode.String.html#split/2-options"},{"type":"function","title":"Examples - Unicode.String.split/2","doc":"iex> Unicode.String.split \"This is a sentence. And another.\", break: :word\n    [\"This\", \" \", \"is\", \" \", \"a\", \" \", \"sentence\", \".\", \" \", \"And\", \" \", \"another\", \".\"]\n\n    iex> Unicode.String.split \"This is a sentence. And another.\", break: :word, trim: true\n    [\"This\", \"is\", \"a\", \"sentence\", \".\", \"And\", \"another\", \".\"]\n\n    iex> Unicode.String.split \"This is a sentence. And another.\", break: :sentence\n    [\"This is a sentence. \", \"And another.\"]","ref":"Unicode.String.html#split/2-examples"},{"type":"function","title":"Unicode.String.splitter/2","doc":"Returns an enumerable that splits a string on demand.","ref":"Unicode.String.html#splitter/2"},{"type":"function","title":"Arguments - Unicode.String.splitter/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of\n  options.","ref":"Unicode.String.html#splitter/2-arguments"},{"type":"function","title":"Returns - Unicode.String.splitter/2","doc":"* A function that implements the enumerable\n  protocol or\n\n* `{:error, reason}`","ref":"Unicode.String.html#splitter/2-returns"},{"type":"function","title":"Options - Unicode.String.splitter/2","doc":"* `:locale` is any locale returned by\n  `Unicode.String.Segment.known_segmentation_locales/0`.\n  The default is \"root\" which corresponds\n  to the break rules defined by the\n  [Unicode Segmentation](https://unicode.org/reports/tr29/) rules.\n\n* `:break` is the type of break. It is one of\n  `:grapheme`, `:word`, `:line` or `:sentence`. The\n  default is `:word`.\n\n* `:suppressions` is a boolean which,\n  if `true`, will suppress breaks for common\n  abbreviations defined for the `locale`. The\n  default is `true`.\n\n* `:trim` is a boolean indicating if segments\n  the are comprised of only white space are to be\n  excluded from the returned list.  The default\n  is `false`.","ref":"Unicode.String.html#splitter/2-options"},{"type":"function","title":"Examples - Unicode.String.splitter/2","doc":"iex> enum = Unicode.String.splitter \"This is a sentence. And another.\", break: :word, trim: true\n    iex> Enum.take enum, 3\n    [\"This\", \"is\", \"a\"]","ref":"Unicode.String.html#splitter/2-examples"},{"type":"function","title":"Unicode.String.stream/2","doc":"Return a stream that breaks a string into\ngraphemes, words, sentences or line breaks.","ref":"Unicode.String.html#stream/2"},{"type":"function","title":"Arguments - Unicode.String.stream/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of\n  options.","ref":"Unicode.String.html#stream/2-arguments"},{"type":"function","title":"Returns - Unicode.String.stream/2","doc":"* A stream that is an `t:Enumerable.t/0` that\n  can be used with the functions in the `Stream`\n  or `Enum` modules.\n\n* `{:error, reason}`","ref":"Unicode.String.html#stream/2-returns"},{"type":"function","title":"Options - Unicode.String.stream/2","doc":"* `:locale` is any locale returned by\n  `Unicode.String.Segment.known_segmentation_locales/0` or\n  a [Cldr.LanguageTag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html)\n  struct. The default is \"root\" which corresponds\n  to the break rules defined by the\n  [Unicode Segmentation](https://unicode.org/reports/tr29/) rules.\n\n* `:break` is the type of break. It is one of\n  `:grapheme`, `:word`, `:line` or `:sentence`. The\n  default is `:word`.\n\n* `:suppressions` is a boolean which,\n  if `true`, will suppress breaks for common\n  abbreviations defined for the `locale`. The\n  default is `true`.\n\n* `:trim` is a boolean indicating if segments\n  the are comprised of only white space are to be\n  excluded from the returned list.  The default\n  is `false`.","ref":"Unicode.String.html#stream/2-options"},{"type":"function","title":"Examples - Unicode.String.stream/2","doc":"iex> Enum.to_list Unicode.String.stream(\"this is a set of words\", trim: true)\n  [\"this\", \"is\", \"a\", \"set\", \"of\", \"words\"]\n\n  iex> Enum.to_list Unicode.String.stream(\"this is a set of words\", break: :sentence, trim: true)\n  [\"this is a set of words\"]","ref":"Unicode.String.html#stream/2-examples"},{"type":"function","title":"Unicode.String.titlecase/2","doc":"Converts the given string to title case\naccording to the Unicode Casing algorithm.\n\nTitle casing is the process of transforming\nthe first character of each word in a string\nto upper case and the following characters\nin the word to lower case.\n\nAs a result this algorithm does not conform\nto the norms of all languages and cultures.\nHowever special processing is performed for\nthe Dutch dipthong \"IJ\" when using the `:nl`\ncasing locale.\n\nFurther work will focus on improving title\ncasing of Greek dipthongs.\n\n#","ref":"Unicode.String.html#titlecase/2"},{"type":"function","title":"Arguments - Unicode.String.titlecase/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of options.\n\n#","ref":"Unicode.String.html#titlecase/2-arguments"},{"type":"function","title":"Options - Unicode.String.titlecase/2","doc":"* `:locale` is any [ISO 639](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes)\n  language code or a [LanguageTag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html)\n  which provides integration with [ex_cldr](https://hex.pm/packages/ex_cldr)\n  applications.  The default is `:any` which signifies the\n  application of the base Unicode casing algorithm.\n\n#","ref":"Unicode.String.html#titlecase/2-options"},{"type":"function","title":"Notes - Unicode.String.titlecase/2","doc":"* The locale option determines the use of certain locale-specific\n  casing rules.  Where no specific casing rules apply to\n  the given locale, the base Unicode casing algorithm is\n  applied. The locales which have customized casing rules\n  are returned by `Unicode.String.special_casing_locales/0`.\n\n* The string is broken into words using\n  `Unicode.String.break/2` which implements the\n  [Unicode segmentation algorithm](https://unicode.org/reports/tr29/).\n\n#","ref":"Unicode.String.html#titlecase/2-notes"},{"type":"function","title":"Returns - Unicode.String.titlecase/2","doc":"* `title_cased_string`.\n\n#","ref":"Unicode.String.html#titlecase/2-returns"},{"type":"function","title":"Examples - Unicode.String.titlecase/2","doc":"iex> Unicode.String.titlecase(\"THE QUICK BROWN FOX\")\n    \"The Quick Brown Fox\"\n\n    # Title case Dutch with leading dipthong\n    iex> Unicode.String.titlecase(\"ijsselmeer\", locale: :nl)\n    \"IJsselmeer\"","ref":"Unicode.String.html#titlecase/2-examples"},{"type":"function","title":"Unicode.String.upcase/2","doc":"Converts all characters in the given string to upper case\naccording to the Unicode Casing algorithm.\n\n#","ref":"Unicode.String.html#upcase/2"},{"type":"function","title":"Arguments - Unicode.String.upcase/2","doc":"* `string` is any `t:String.t/0`.\n\n* `options` is a keyword list of options.\n\n#","ref":"Unicode.String.html#upcase/2-arguments"},{"type":"function","title":"Options - Unicode.String.upcase/2","doc":"* `:locale` is any [ISO 639](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes)\n  language code or a [LanguageTag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html)\n  which provides integration with [ex_cldr](https://hex.pm/packages/ex_cldr)\n  applications.  The default is `:any` which signifies the\n  application of the base Unicode casing algorithm.\n\n#","ref":"Unicode.String.html#upcase/2-options"},{"type":"function","title":"Notes - Unicode.String.upcase/2","doc":"* The locale option determines the use of certain locale-specific\n  casing rules.  Where no specific casing rules apply to\n  the given locale, the base Unicode casing algorithm is\n  applied. The locales which have customized casing rules\n  are returned by `Unicode.String.special_casing_locales/0`.\n\n#","ref":"Unicode.String.html#upcase/2-notes"},{"type":"function","title":"Returns - Unicode.String.upcase/2","doc":"* `downcased_string`\n\n#","ref":"Unicode.String.html#upcase/2-returns"},{"type":"function","title":"Examples - Unicode.String.upcase/2","doc":"# Basic case transformation\n    iex> Unicode.String.upcase(\"the quick brown fox\")\n    \"THE QUICK BROWN FOX\"\n\n    # Dotted-I in Turkish and Azeri\n    iex> Unicode.String.upcase(\"Diyarbakır\", locale: :tr)\n    \"DİYARBAKIR\"\n\n    # Upper case in Greek removes diacritics\n    iex> Unicode.String.upcase(\"Πατάτα, Αέρας, Μυστήριο\", locale: :el)\n    \"ΠΑΤΑΤΑ, ΑΕΡΑΣ, ΜΥΣΤΗΡΙΟ\"","ref":"Unicode.String.html#upcase/2-examples"},{"type":"type","title":"Unicode.String.break_match/0","doc":"","ref":"Unicode.String.html#t:break_match/0"},{"type":"type","title":"Unicode.String.break_or_no_break/0","doc":"","ref":"Unicode.String.html#t:break_or_no_break/0"},{"type":"type","title":"Unicode.String.break_type/0","doc":"","ref":"Unicode.String.html#t:break_type/0"},{"type":"type","title":"Unicode.String.error_return/0","doc":"","ref":"Unicode.String.html#t:error_return/0"},{"type":"type","title":"Unicode.String.mode_or_language/0","doc":"","ref":"Unicode.String.html#t:mode_or_language/0"},{"type":"type","title":"Unicode.String.options/0","doc":"","ref":"Unicode.String.html#t:options/0"},{"type":"type","title":"Unicode.String.split_options/0","doc":"","ref":"Unicode.String.html#t:split_options/0"},{"type":"type","title":"Unicode.String.string_interval/0","doc":"","ref":"Unicode.String.html#t:string_interval/0"},{"type":"module","title":"Unicode.String.Break","doc":"Implements the Unicode break algorithm","ref":"Unicode.String.Break.html"},{"type":"module","title":"Unicode.String.Case.Folding","doc":"Implements the Unicode Case Folding algorithm.\n\nThe intention of case folding is to facilitate\ncase-insensitive string comparisons. It is not\nintended to be a general purpose transformation.\n\nAlthough case folding does generally use lower\ncase as its normal form, it is not true for\nall scripts and codepoints.  Therefore case\nfolding should not be used as an alternative\nto `String.downcase/1`.","ref":"Unicode.String.Case.Folding.html"},{"type":"function","title":"Unicode.String.Case.Folding.fold/1","doc":"Case fold a string.\n\nReturns a string after applying the Unicode\nCase Folding algorithm.\n\nCase folding is intended to suport case\ninsensitve string comparisons such as that\nimplemented by `Unicode.String.equals_ignoring_case?/2` which\ncalls this function on its parameters.\n\n#","ref":"Unicode.String.Case.Folding.html#fold/1"},{"type":"function","title":"Arguments - Unicode.String.Case.Folding.fold/1","doc":"* `string` is any `String.t()`\n\n* `mode or language tag` is either the atoms `:turkic` or `nil`\n  or a map that includes the key `:language` with a value that\n  is a lowercase atom representing an [ISO 639-1](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes)\n  language code. The [CLDR language tag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html) which is defined\n  as part of the [ex_cldr](https://hex.pm/packages/ex_cldr) is one\n  such example. See [Cldr.validate_locale/2](https://hexdocs.pm/ex_cldr/Cldr.html#validate_locale/2)\n  for further information. The default is `nil`.\n\n#","ref":"Unicode.String.Case.Folding.html#fold/1-arguments"},{"type":"function","title":"Returns - Unicode.String.Case.Folding.fold/1","doc":"* The case folded string\n\n#","ref":"Unicode.String.Case.Folding.html#fold/1-returns"},{"type":"function","title":"Notes - Unicode.String.Case.Folding.fold/1","doc":"* No normalization is applied to the\n  string on either input or output.\n\n* Case folding does not apply any transformation\n  to accented characters. `\"ü\"` will not case fold\n  to `\"u\"` for example.\n\n#","ref":"Unicode.String.Case.Folding.html#fold/1-notes"},{"type":"function","title":"Examples - Unicode.String.Case.Folding.fold/1","doc":"iex> Unicode.String.Case.Folding.fold(\"THIS\")\n    \"this\"\n\n    iex> Unicode.String.Case.Folding.fold(\"grüßen\")\n    \"grüssen\"\n\n    iex(13)> Unicode.String.Case.Folding.fold(\"I\")\n    \"i\"\n\n    # Turkic languages such as Turkish and Azerbaijani have\n    # a dotless lower case \"i\"\n    iex> Unicode.String.Case.Folding.fold(\"I\", :turkic)\n    \"ı\"\n\n    iex> Unicode.String.Case.Folding.fold(\"I\", %{language: :az})\n    \"ı\"","ref":"Unicode.String.Case.Folding.html#fold/1-examples"},{"type":"function","title":"Unicode.String.Case.Folding.fold/2","doc":"","ref":"Unicode.String.Case.Folding.html#fold/2"},{"type":"module","title":"Unicode.String.Case.Mapping","doc":"The [Unicode Case Mapping](https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf) algorithm\ndefines the process and data to transform text into upper case, lower case or title case.\n\nSince most languages are not bicameral, characters which have no appropriate mapping remain unchanged.\n\nThree case mapping functions are provided as a public API which have their implementations in this module:\n\n* `Unicode.String.upcase/2` which will convert text to upper case characters.\n* `Unicode.String.downcase/2` which will convert text to lower case characters.\n* `Unicode.String.titlecase/2` which will convert text to title case.  Title case means\n  that the first character or each word is set to upper case and all other characters in\n  the word are set to lower case. `Unicode.String.split/2` is used to split the string\n  into words before title casing.\n\nEach function operates in a locale-aware manner implementing some basic capabilities:\n\n* Casing rules for the Turkish dotted capital `I` and dotless small `i`.\n* Casing rules for the retention of dots over `i` for Lithuanian letters with additional accents.\n* Titlecasing of IJ at the start of words in Dutch.\n* Removal of accents when upper casing letters in Greek.\n\nThere are other casing rules that are not currently implemented such as:\n\n* Titlecasing of second or subsequent letters in words in orthographies that include\n  caseless letters such as apostrophes.\n* Uppercasing of U+00DF `ß` latin small letter sharp `s` to U+1E9E `ẞ` latin capital letter\n  sharp `s`.\n\n#","ref":"Unicode.String.Case.Mapping.html"},{"type":"module","title":"Examples - Unicode.String.Case.Mapping","doc":"# Basic case transformation\n    iex> Unicode.String.Case.Mapping.upcase(\"the quick brown fox\")\n    \"THE QUICK BROWN FOX\"\n\n    # Dotted-I in Turkish and Azeri\n    iex> Unicode.String.Case.Mapping.upcase(\"Diyarbakır\", :tr)\n    \"DİYARBAKIR\"\n\n    # Upper case in Greek removes diacritics\n    iex> Unicode.String.Case.Mapping.upcase(\"Πατάτα, Αέρας, Μυστήριο\", :el)\n    \"ΠΑΤΑΤΑ, ΑΕΡΑΣ, ΜΥΣΤΗΡΙΟ\"\n\n    # Lower case Greek with a final sigma\n    iex> Unicode.String.Case.Mapping.downcase(\"ὈΔΥΣΣΕΎΣ\", :el)\n    \"ὀδυσσεύς\"\n\n    # Title case Dutch with leading dipthong\n    iex> Unicode.String.Case.Mapping.titlecase(\"ijsselmeer\", :nl)\n    \"IJsselmeer\"","ref":"Unicode.String.Case.Mapping.html#module-examples"},{"type":"function","title":"Unicode.String.Case.Mapping.downcase/2","doc":"Replace upper case characters with their\nlower case equivalents.","ref":"Unicode.String.Case.Mapping.html#downcase/2"},{"type":"function","title":"Unicode.String.Case.Mapping.titlecase/2","doc":"Apply to Unicode title case algorithm.","ref":"Unicode.String.Case.Mapping.html#titlecase/2"},{"type":"function","title":"Unicode.String.Case.Mapping.upcase/2","doc":"Replace lower case characters with their\nuppercase equivalents.\n\nLower case characters are replaced with their\nupper case equivalents. All other characters\nremain unchanged.\n\nFor the Greek language (`:el`), all accents are\nremoved prior to capitalization as is the normal\npractise for this language.","ref":"Unicode.String.Case.Mapping.html#upcase/2"},{"type":"module","title":"Unicode.String.Case.Mapping.Greek","doc":"Implements the special upper casing rules for\nfor the Greek language.","ref":"Unicode.String.Case.Mapping.Greek.html"},{"type":"function","title":"Unicode.String.Case.Mapping.Greek.upcase/1","doc":"This implementation currently implements the `el-Upper` transform\nfrom CLDR.\n\n#","ref":"Unicode.String.Case.Mapping.Greek.html#upcase/1"},{"type":"function","title":"CLDR algorithm - Unicode.String.Case.Mapping.Greek.upcase/1","doc":"According to CLDR all accents on all characters are are omitted when\nupcasing.\n\n  Remove 0301 following Greek, with possible intervening 0308 marks.\n  ::NFD();\n  For uppercasing (not titlecasing!) remove all greek accents from greek letters.\n  This is done in two groups, to account for canonical ordering.\n  [:Greek:] [^[:ccc=Not_Reordered:][:ccc=Above:]]*? { [̓̔́̀̆͂̈̄] → ;\n  [:Greek:] [^[:ccc=Not_Reordered:][:ccc=Iota_Subscript:]]*? { ͅ → ;\n  ::NFC();\n\nThat transform basically says remove all accents except a\nsubscripted iota. It doesn't handle dipthongs correctly.\n\n#","ref":"Unicode.String.Case.Mapping.Greek.html#upcase/1-cldr-algorithm"},{"type":"function","title":"Mozilla algorithm - Unicode.String.Case.Mapping.Greek.upcase/1","doc":"Mozilla has a thread on a [bug report](https://bugzilla.mozilla.org/show_bug.cgi?id=307039)\nthat:\n\n>  Greek accented letters should be converted to the respective non-accented uppercase\n>  letters. The required conversions are the following (in Unicode):\n>\n>  ά -> Α\n>  έ -> Ε\n>  ή -> Η\n>  ί -> Ι\n>  ΐ -> Ϊ\n>  ό -> Ο\n>  ύ -> Υ\n>  ΰ -> Ϋ\n>  ώ -> Ω\n>\n>  Also diphthongs (two-vowel constructs) should be converted as follows, when the\n>  first vowel is accented:\n>\n>  άι -> ΑΪ\n>  έι -> ΕΪ\n>  όι -> ΟΪ\n>  ύι -> ΥΪ\n>  άυ -> ΑΫ\n>  έυ -> ΕΫ\n>  ήυ -> ΗΫ\n>  όυ -> ΟΫ\n\nThat thread seems to align with current-day [Mozilla](https://developer.mozilla.org/en-US/docs/Web/CSS/text-transform)\nwhich says the rules are:\n\n> In Greek (el), vowels lose their accent when the whole word is in\n> uppercase (ά/Α), except for the disjunctive eta (ή/Ή). Also, diphthongs\n> with an accent on the first vowel lose the accent and gain a diaeresis\n> on the second vowel (άι/ΑΪ).","ref":"Unicode.String.Case.Mapping.Greek.html#upcase/1-mozilla-algorithm"},{"type":"module","title":"Unicode.String.Segment","doc":"Implements the compilation of the Unicode\nsegment rules.","ref":"Unicode.String.Segment.html"},{"type":"function","title":"Unicode.String.Segment.ancestors/1","doc":"Returns a list of the ancestor locales\nof the a given locale.\n\nThe list includes the given locale.","ref":"Unicode.String.Segment.html#ancestors/1"},{"type":"function","title":"Unicode.String.Segment.compile_rule/3","doc":"Compiles a segment rule in the context of a list\nof variables.\n\nThe compile rule can then be inserted into a\nrule set.","ref":"Unicode.String.Segment.html#compile_rule/3"},{"type":"function","title":"Unicode.String.Segment.compile_rules/3","doc":"","ref":"Unicode.String.Segment.html#compile_rules/3"},{"type":"function","title":"Unicode.String.Segment.evaluate_rules/2","doc":"Evaluates a list of rules against a given\nstring.","ref":"Unicode.String.Segment.html#evaluate_rules/2"},{"type":"function","title":"Unicode.String.Segment.expand_variables/2","doc":"","ref":"Unicode.String.Segment.html#expand_variables/2"},{"type":"macro","title":"Unicode.String.Segment.is_id_continue/1","doc":"Identifies if a codepoint is a valid identifier character","ref":"Unicode.String.Segment.html#is_id_continue/1"},{"type":"macro","title":"Unicode.String.Segment.is_id_start/1","doc":"Identifies if a codepoint is a valid start of an identifier","ref":"Unicode.String.Segment.html#is_id_start/1"},{"type":"function","title":"Unicode.String.Segment.known_segmentation_locales/0","doc":"Returns a list of the known locales that have\nsegmentation data.","ref":"Unicode.String.Segment.html#known_segmentation_locales/0"},{"type":"function","title":"Unicode.String.Segment.rules/3","doc":"Return the rules as defined by CLDR for a given\nlocale and break type.","ref":"Unicode.String.Segment.html#rules/3"},{"type":"function","title":"Unicode.String.Segment.rules!/3","doc":"Return the rules as defined by CLDR for a given\nlocale and break type and raises on error.","ref":"Unicode.String.Segment.html#rules!/3"},{"type":"function","title":"Unicode.String.Segment.suppressions/2","doc":"Returns a list of the suppressions for a given\nlocale and segment type.","ref":"Unicode.String.Segment.html#suppressions/2"},{"type":"function","title":"Unicode.String.Segment.suppressions!/2","doc":"Returns a list of the suppressions for a given\nlocale and segment type and raises on error.","ref":"Unicode.String.Segment.html#suppressions!/2"},{"type":"extras","title":"Unicode String","doc":"# Unicode String\n\n![Build status](https://github.com/elixir-unicode/unicode_string/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/unicode_string.svg)](https://hex.pm/packages/unicode_string)\n[![Hex.pm](https://img.shields.io/hexpm/dw/unicode_string.svg?)](https://hex.pm/packages/unicode_string)\n[![Hex.pm](https://img.shields.io/hexpm/l/unicode_string.svg)](https://hex.pm/packages/unicode_string)\n\nAdds functions supporting some string algorithms in the Unicode standard. For example:\n\n* The [Unicode Case Folding](https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf) algorithm to provide case-independent equality checking irrespective of language or script with `Unicode.String.fold/2` and `Unicode.String.equals_ignoring_case?/2`\n\n* The [Unicode Code Mapping](https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf) algorithm that implements locale-aware `Unicode.String.upcase/2`, `Unicode.String.downcase/2` and `Unicode.String.titlecase/2`.\n\n* The [Unicode Segmentation](https://unicode.org/reports/tr29/) algorithm to detect, break, split or stream strings into grapheme clusters, words, sentences and line break points in a locale-aware manner.\n\n* The [Unicode Line Breaking](https://www.unicode.org/reports/tr14/) algorithm to determine line breaks (breaks meaning where word-wrapping would be acceptable).","ref":"readme.html"},{"type":"extras","title":"Casing - Unicode String","doc":"#","ref":"readme.html#casing"},{"type":"extras","title":"Case Folding - Unicode String","doc":"The [Unicode Case Folding](https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf) algorithm defines how to perform case folding. This allows comparison of strings in a case-insensitive fashion. It does not define the means to compare ignoring diacritical marks (accents). Some examples follow, for details see:\n\n* `Unicode.String.fold/2`\n* `Unicode.String.equals_ignoring_case?/3`\n\n> ##","ref":"readme.html#case-folding"},{"type":"extras","title":"Note {: .info} - Unicode String","doc":">\n> Although the folding algorithm commonly downcases characters, folding is not a general purpose downcasing process. It exists only to facilitate case insensitive string comparison.\n\n\n```elixir\niex> Unicode.String.equals_ignoring_case? \"ABC\", \"abc\"\ntrue\n\niex> Unicode.String.equals_ignoring_case? \"beißen\", \"beissen\"\ntrue\n\niex> Unicode.String.equals_ignoring_case? \"grüßen\", \"grussen\"\nfalse\n```\n\n#","ref":"readme.html#note-info"},{"type":"extras","title":"Case Mapping - Unicode String","doc":"The [Unicode Case Mapping](https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf) algorithm defines the process and data to transform text into upper case, lower case or title case. Since most languages are not bicameral, characters which have no case mapping remain unchanged.\n\nThree case mapping functions are provided:\n\n* `Unicode.String.upcase/2` which will convert text to upper case characters.\n* `Unicode.String.downcase/2` which will convert text to lower case characters.\n* `Unicode.String.titlecase/2` which will convert text to title case.  Title case means that the first character or each word is set to upper case and all other characters in the word are set to lower case. `Unicode.String.split/2` is used to split the string into words before title casing.\n\nEach function operates in a locale-aware manner implementing some basic capabilities:\n\n* Casing rules for the Turkish dotted capital `I` and dotless small `i`.\n* Casing rules for the retention of dots over `i` for Lithuanian letters with additional accents.\n* Titlecasing of IJ at the start of words in Dutch.\n* Removal of accents when upper casing letters in Greek.\n\nThere are other casing rules that are not currently implemented such as:\n\n* Titlecasing of second or subsequent letters in words in orthographies that include caseless letters such as apostrophes.\n* Uppercasing of U+00DF `ß` latin small letter sharp `s` to U+1E9E `ẞ` latin capital letter sharp `s`.\n\n```elixir\n# Basic case transformation\niex> Unicode.String.upcase(\"the quick brown fox\")\n\"THE QUICK BROWN FOX\"\n\n# Dotted-I in Turkish and Azeri\niex> Unicode.String.upcase(\"Diyarbakır\", locale: :tr)\n\"DİYARBAKIR\"\n\n# Upper case in Greek removes diacritics\niex> Unicode.String.upcase(\"Πατάτα, Αέρας, Μυστήριο\", locale: :el)\n\"ΠΑΤΑΤΑ, ΑΕΡΑΣ, ΜΥΣΤΗΡΙΟ\"\n\n# Lower case Greek with a final sigma\niex> Unicode.String.downcase(\"ὈΔΥΣΣΕΎΣ\", locale: :el)\n\"ὀδυσσεύς\"\n\n# Title case Dutch with leading dipthong\niex> Unicode.String.titlecase(\"ijsselmeer\", locale: :nl)\n\"IJsselmeer\"\n```","ref":"readme.html#case-mapping"},{"type":"extras","title":"Segmentation - Unicode String","doc":"The [Unicode Segmentation](https://unicode.org/reports/tr29/) annex details the algorithm to be applied with segmenting text (Elixir strings) into words, sentences, graphemes and line breaks. Some examples follow, for details see:\n\n* `Unicode.String.split/2`\n* `Unicode.String.break?/2`\n* `Unicode.String.break/2`\n* `Unicode.String.splitter/2`\n* `Unicode.String.next/2`\n* `Unicode.String.stream/2`\n\n```elixir\n# Split text at a word boundary.\niex> Unicode.String.split \"This is a sentence. And another.\", break: :word\n[\"This\", \" \", \"is\", \" \", \"a\", \" \", \"sentence\", \".\", \" \", \"And\", \" \", \"another\", \".\"]\n\n# Split text at a word boundary but omit any whitespace\niex> Unicode.String.split \"This is a sentence. And another.\", break: :word, trim: true\n[\"This\", \"is\", \"a\", \"sentence\", \".\", \"And\", \"another\", \".\"]\n\n# Split text at a sentence boundary.\niex> Unicode.String.split \"This is a sentence. And another.\", break: :sentence\n[\"This is a sentence. \", \"And another.\"]\n\n# By default, common abbreviations are suppressed (ie\n# the do not cause a break)\niex> Unicode.String.split \"No, I don't have a Ph.D. but I don't think it matters.\", break: :word, trim: true\n[\"No\", \",\", \"I\", \"don't\", \"have\", \"a\", \"Ph.D\", \".\", \"but\", \"I\", \"don't\",\n \"think\", \"it\", \"matters\", \".\"]\n\niex> Unicode.String.split \"No, I don't have a Ph.D. but I don't think it matters.\", break: :sentence, trim: true\n[\"No, I don't have a Ph.D. but I don't think it matters.\"]\n\n# Sentence Break suppressions are locale sensitive.\niex> Unicode.String.Segment.known_locales\n[\"de\", \"el\", \"en\", \"en-US\", \"en-US-POSIX\", \"es\", \"fi\", \"fr\", \"it\", \"ja\", \"pt\",\n \"root\", \"ru\", \"sv\", \"zh\", \"zh-Hant\"]\n\niex> Unicode.String.split \"Non, c'est M. Dubois.\", break: :sentence, trim: true, locale: \"fr\"\n[\"Non, c'est M. Dubois.\"]\n\n# Note that break: :line does NOT mean split the string\n# at newlines. It splits the string where a line break would be\n# acceptable. This is very useful for calculating where\n# to perform word-wrap on some text.\niex> Unicode.String.split \"This is a sentence. And another.\", break: :line\n[\"This \", \"is \", \"a \", \"sentence. \", \"And \", \"another.\"]\n```","ref":"readme.html#segmentation"},{"type":"extras","title":"Segment Streaming - Unicode String","doc":"Segmentation can also be streamed using `Unicode.String.stream/2`. For large strings this may improve memory usage since the intermediate segments will be garbage collected when they fall out of scope.\n\n```elixir\niex> Enum.to_list Unicode.String.stream(\"this is a set of words\", trim: true)                       [\"this\", \"is\", \"a\", \"set\", \"of\", \"words\"]\n\niex> Enum.map Unicode.String.stream(\"this is a set of words\", trim: true),\n...>   fn word -> %{word: word, length: String.length(word)} end\n[\n  %{length: 4, word: \"this\"},\n  %{length: 2, word: \"is\"},\n  %{length: 1, word: \"a\"},\n  %{length: 3, word: \"set\"},\n  %{length: 2, word: \"of\"},\n  %{length: 5, word: \"words\"}\n]\n```","ref":"readme.html#segment-streaming"},{"type":"extras","title":"Installation - Unicode String","doc":"The package can be installed by adding `:unicode_string` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:unicode_string, \"~> 1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2018-2023 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"Unicode String v1.3.0 - Changelog","doc":"This is the changelog for Unicode String v1.3.0 released on August 16th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#unicode-string-v1-3-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix case folding for codepoints that fold to themselves.\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds case mapping functions `Unicode.String.upcase/2`, `Unicode.String.downcase/2` and `Unicode/String.titlecase/2`. These functions implement the full [Unicode Casing algorithm](https://www.unicode.org/versions/Unicode15.0.0/ch03.pdf) including conditiional mappings. They are locale-aware and a locale can be specified as a string, atom or a [Cldr.LanguageTag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html) thereby providing basic integration between `unicode_string` and [ex_cldr](https://hex.pm/packages/ex_cldr).\n\n* Case folding always follows the `:full` path which allows mapping of single code points to multiple code points. There is no practical reason to implement the `:simple` path. As a result, the `type` parameter to `Unicode.String.Case.Folding.fold/2` is no longer required or supported.\n\n* Support an [ex_cldr](https://hex.pm/packages/ex_cldr) [Language Tag](https://hexdocs.pm/ex_cldr/Cldr.LanguageTag.html) as a parameter to `Unicode.String.Case.Folding.fold/2`. In fact any map that has a `:language` key with a value that is an [ISO 639-1](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) language code as a lower cased atom may be passed as a parameter.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode String v1.2.1 - Changelog","doc":"This is the changelog for Unicode String v1.2.1 released on June 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#unicode-string-v1-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Resolve segments dir at runtime, not compile time. Thanks to @crkent for the report. Closes #4.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode String v1.2.0 - Changelog","doc":"This is the changelog for Unicode String v1.2.0 released on March 14th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#unicode-string-v1-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Unicode.String.stream/2` to support streaming graphemes, words, sentences and line breaks.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode String v1.1.0 - Changelog","doc":"This is the changelog for Unicode String v1.1.0 released on September 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#unicode-string-v1-1-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates the segmentation supplemental data (including locales) for CLDR. This adds the \"sv\" and \"fi\" locale data for sentence break suppressions.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode String v1.0.1 - Changelog","doc":"This is the changelog for Unicode String v1.0.1 released on September 15th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#unicode-string-v1-0-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Woops, the priv/segments directory was not included in the build artifact","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Unicode String v1.0.0 - Changelog","doc":"This is the changelog for Unicode String v1.0.0 released on September 14th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#unicode-string-v1-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to use [Unicode 14](https://unicode.org/versions/Unicode14.0.0) release data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Unicode String v0.3.0 - Changelog","doc":"This is the changelog for Unicode String v0.3.0 released on October 11th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#unicode-string-v0-3-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correct deps and docs to align with Elixir 1.11 and recent releases of `ex_unicode`.\n\n# Unicode String v0.2.0\n\nThis is the changelog for Unicode String v0.2.0 released on July 12th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"This release implements the Unicode break rules for graphemes, words, lines (word-wrapping) and sentences.\n\n* Adds `Unicode.String.split/2`\n\n* Adds `Unicode.String.break?/2`\n\n* Adds `Unicode.String.break/2`\n\n* Adds `Unicode.String.splitter/2`\n\n* Adds `Unicode.String.next/2`\n\n# Unicode String v0.1.0\n\nThis is the changelog for Unicode String v0.1.0 released on May 17th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-unicode/unicode_string/tags)\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Initial release","ref":"changelog.html#enhancements"}],"content_type":"text/markdown"}